==> opennms-util-1.7.91-sources.jar: org/opennms/core/utils/MatchTable.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//
/**
 * 
 */
package org.opennms.core.utils;

import java.util.regex.Matcher;


public class MatchTable implements PropertiesUtils.SymbolTable {
    
    private Matcher m_matcher;

    public MatchTable(Matcher m) {
        m_matcher = m;
    }

    public String getSymbolValue(String symbol) {
        try {
            int groupNum = Integer.parseInt(symbol);
            if (groupNum > m_matcher.groupCount())
                return null;
            return m_matcher.group(groupNum);
        } catch (NumberFormatException e) {
            return null;
        }
    }
    
}

==> opennms-util-1.8.3-sources.jar: org/opennms/core/utils/MatchTable.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//
/**
 * <p>MatchTable class.</p>
 *
 * @author ranger
 * @version $Id: $
 */
package org.opennms.core.utils;

import java.util.regex.Matcher;
public class MatchTable implements PropertiesUtils.SymbolTable {
    
    private Matcher m_matcher;

    /**
     * <p>Constructor for MatchTable.</p>
     *
     * @param m a {@link java.util.regex.Matcher} object.
     */
    public MatchTable(Matcher m) {
        m_matcher = m;
    }

    /** {@inheritDoc} */
    public String getSymbolValue(String symbol) {
        try {
            int groupNum = Integer.parseInt(symbol);
            if (groupNum > m_matcher.groupCount())
                return null;
            return m_matcher.group(groupNum);
        } catch (NumberFormatException e) {
            return null;
        }
    }
    
}
